﻿// Elevator.cs
// by Dickson Cho
// August 2016
using UnityEngine;
using System.Collections;

public enum ElevatorState
{
	eGoingUp,
	eWaitingAtTop,
	eGoingDown,
	eWaitingAtBottom,

	MAX_STATES
}

/// <summary>
/// Elevator class to control behavior for all elevators in the game
/// </summary>
public class Elevator : MonoBehaviour
{
	public Transform m_Bottom;
	public Transform m_Top;
	public float m_SecondsPerTrip;
	public float m_SecondsToWait;

	private float m_CurrentLerpProgress;		// Between 0.0f and 1.0f
	private float m_CurrentWaitProgress;		// Number of seconds we've been waiting
	private ElevatorState m_State;

	private void Start()
	{
		m_State = ElevatorState.eGoingUp;
		m_CurrentLerpProgress = 0.0f;
		m_CurrentWaitProgress = m_SecondsToWait;
	}

	private void Update()
	{
		switch (m_State)
		{
			case ElevatorState.eGoingUp:
				m_CurrentLerpProgress += Time.deltaTime / m_SecondsPerTrip;
				transform.position = Vector3.Lerp(m_Bottom.position, m_Top.position, m_CurrentLerpProgress);
				if (m_CurrentLerpProgress >= 1.0f)
				{
					m_State = ElevatorState.eWaitingAtTop;
					m_CurrentLerpProgress = 0.0f;
				}
				break;
			case ElevatorState.eWaitingAtTop:
				m_CurrentWaitProgress -= Time.deltaTime;
				if (m_CurrentWaitProgress <= 0.0f)
				{
					m_State = ElevatorState.eGoingDown;
					m_CurrentWaitProgress = m_SecondsToWait;
				}
				break;
			case ElevatorState.eGoingDown:
				m_CurrentLerpProgress += Time.deltaTime / m_SecondsPerTrip;
				transform.position = Vector3.Lerp(m_Top.position, m_Bottom.position, m_CurrentLerpProgress);
				if (m_CurrentLerpProgress >= 1.0f)
				{
					m_State = ElevatorState.eWaitingAtBottom;
					m_CurrentLerpProgress = 0.0f;
				}
				break;
			case ElevatorState.eWaitingAtBottom:
				m_CurrentWaitProgress -= Time.deltaTime;
				if (m_CurrentWaitProgress <= 0.0f)
				{
					m_State = ElevatorState.eGoingUp;
					m_CurrentWaitProgress = m_SecondsToWait;
				}
				break;
		}
	}
}
