﻿// InputManager.cs
// by Dickson Cho
// August 2016
using UnityEngine;
using System.Collections;

/// <summary>
/// Input manager consumes input and interacts with the character controller. This
/// is the class where you determine what "holding down W" means, or "swiping up",
/// or "pushing both thumbsticks forward"
/// </summary>
public class InputManager : MonoBehaviour
{
	public ICharacterController m_PlayerController;			// Drag and drop the player object here
	public CameraController m_CameraController;				// Drag and drop the camera object here

	private void Update()
	{
		GameState currentState = GameManager.GetInstance().m_State;

		switch (currentState)
		{
			case GameState.eWatchingBillboard:
				if (Input.anyKeyDown)
				{
					GameManager.GetInstance().AdvanceGameState();
				}
				break;
			case GameState.eFlyingIntroCamera:
				// Wait for intro to finish flying before we let them play
				if (Input.anyKeyDown)
				{
					GameObject.Find("CameraRig").GetComponent<CameraController>().SkipIntro();
				}
				break;
			case GameState.eInGame:
				UpdateMovement();
				UpdateRotation();
				UpdateMisc();
				break;
			default:
				// Unknown state!
				break;
		}
	}

	/// <summary>
	/// Updates all translation based on input
	/// </summary>
	private void UpdateMovement()
	{
		if (Input.GetKey(KeyCode.W))
		{
			m_PlayerController.MoveForward();
		}
		if (Input.GetKey(KeyCode.S))
		{
			m_PlayerController.MoveBackward();
		}
		if (Input.GetKey(KeyCode.A))
		{
			m_PlayerController.MoveLeft();
		}
		if (Input.GetKey(KeyCode.D))
		{
			m_PlayerController.MoveRight();
		}
	}

	/// <summary>
	/// Updates all rotation based on input
	/// </summary>
	private void UpdateRotation()
	{
		if (Input.GetKey(KeyCode.Q))
		{
			m_CameraController.RotateLeft();
		}
		if (Input.GetKey(KeyCode.E))
		{
			m_CameraController.RotateRight();
		}
	}

	/// <summary>
	/// Updates for other button presses
	/// </summary>
	private void UpdateMisc()
	{
		// Instantly quit the game
		if (Input.GetKey(KeyCode.Escape))
		{
			Application.Quit();
		}

		// Just in case the player gets stuck
		if (Input.GetKey(KeyCode.Space))
		{
			m_PlayerController.Reset();
		}
	}
}
