﻿// IntroScene.cs
// by Dickson Cho
// August 2016
using UnityEngine;
using UnityEngine.UI;
using System.Collections;

/// <summary>
/// This details the current state of the intro
/// </summary>
enum SceneState
{
	eDicksonChoPresents,
	eCreationDate,
	eTitleScreen,

	MAX_STATES
}

/// <summary>
/// This is used specifically to handle any logic related to the intro scene
/// </summary>
public class IntroScene : MonoBehaviour
{
	public Text m_SmallCenterText;
	public float m_SecondsBeforeLoading;

	private SceneState m_State;
	private bool m_Triggered = false;

	private void Start()
	{
		m_State = SceneState.eDicksonChoPresents;
		m_SmallCenterText.text = "Dickson Cho\nproudly presents";
	}
	
	private void Update()
	{
		switch (m_State)
		{
			case SceneState.eDicksonChoPresents:
				UpdateDicksonChoPresents();
				break;
			case SceneState.eCreationDate:
				UpdateCreationDate();
				break;
			case SceneState.eTitleScreen:
				UpdateTitleScreen();
				break;
			default:
				break;
		}

		if (Input.GetKeyDown(KeyCode.Escape))
		{
			// At any time, let the user leave
			Application.Quit();
		}
		else if (Input.anyKeyDown)
		{
			// Skip the intro
			Application.LoadLevel("LevelOne");
		}
	}

	private void UpdateDicksonChoPresents()
	{
		Animator anim = m_SmallCenterText.GetComponent<Animator>();
		if (!m_Triggered && (anim != null) && (anim.GetCurrentAnimatorStateInfo(0).IsName("ReadyToAnimate")))
		{
			// Trigger the animation
			anim.SetTrigger("triggerAnim");
			m_Triggered = true;
		}
		else if (m_Triggered && (anim != null) && (anim.GetCurrentAnimatorStateInfo(0).IsName("FinishedAnimation")))
		{
			// Transition to the creation state
			anim.SetTrigger("resetAnim");
			m_Triggered = false;
			m_State = SceneState.eCreationDate;
			m_SmallCenterText.text = "a game he created\non August 2016";
		}
	}
	
	private void UpdateCreationDate()
	{
		Animator anim = m_SmallCenterText.GetComponent<Animator>();
		if (!m_Triggered && (anim != null) && (anim.GetCurrentAnimatorStateInfo(0).IsName("ReadyToAnimate")))
		{
			// Trigger the animation
			anim.SetTrigger("triggerAnim");
			m_Triggered = true;
		}
		else if (m_Triggered && (anim != null) && (anim.GetCurrentAnimatorStateInfo(0).IsName("FinishedAnimation")))
		{
			// Transition to the title state
			anim.SetTrigger("resetAnim");
			m_Triggered = false;
			m_State = SceneState.eTitleScreen;
		}
	}

	private void UpdateTitleScreen()
	{
		// Remember, the user can press any key to continue, AT ANY TIME

		// Let's wait a bit before loading; this gives the song a chance to finish
		m_SecondsBeforeLoading -= Time.deltaTime;
		if (m_SecondsBeforeLoading <= 0.0f)
		{
			Application.LoadLevel("LevelOne");
		}
	}
}
