﻿// StickyObject.cs
// by Dickson Cho
// August 2016
using UnityEngine;
using System.Collections;

/// <summary>
/// This represents an object in the world which can be picked up by
/// the player ball
/// </summary>
public class StickyObject : MonoBehaviour
{
	public float m_MinBallRadius;		// The ball must be at least this size to pick this up
	public int m_Kilograms;				// The amount of mass this object contains

	/// <summary>
	/// Can we stick to the player ball?
	/// </summary>
	/// <param name="ballRadius">The current radius of the player ball</param>
	/// <returns>Returns TRUE if we can be picked up by the player</returns>
	public bool CanStick(float ballRadius)
	{
		return (m_MinBallRadius <= ballRadius);
	}

	/// <summary>
	/// Stick ourselves to the specified game object
	/// </summary>
	/// <param name="ball">The game object to stick to; typically the player ball</param>
	public void Stick(GameObject ball)
	{
		// Make ourselves a child of the ball and remove all physics
		transform.parent = ball.transform;
		Destroy(gameObject.GetComponent<Rigidbody>());
		
		// Play the pick-up sound. If this were a larger project, I would have an audio manager
		// complete with volume control, mute, and all the good stuff.
		GetComponent<AudioSource>().Play();

		// Inform the game manager of our collection
		GameManager.GetInstance().CollectMass(m_Kilograms);
	}
	
	private void OnTriggerEnter(Collider other)
	{
		if (other.gameObject.tag == "Player")
		{
			// Got touched by the player ball! Check the ball's radius
			Player playerScript = other.gameObject.GetComponent<Player>();
			if ((playerScript != null) && CanStick(playerScript.GetBallRadius()))
			{
				Stick(other.gameObject);
			}
		}
	}
}
